#ifndef NT2_INCLUDE_FUNCTIONS_ASEC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASEC_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/asec.hpp>

#endif
